=== modified file 'bzrlib/selftest/treeshape.py'
--- bzrlib/selftest/treeshape.py	2005-10-04 09:54:26 +0000
+++ bzrlib/selftest/treeshape.py	2005-10-04 10:10:48 +0000
@@ -28,6 +28,9 @@
 # comparison.
 
 import os
+import stat
+
+from bzrlib.trace import warning
 
 def build_tree_contents(template):
     """Reconstitute some files from a text description.
@@ -52,7 +55,7 @@
                 f.close()
 
 
-def pack_tree_contents(top):
+def capture_tree_contents(top):
     """Make a Python datastructure description of a tree.
     
     If top is an absolute path the descriptions will be absolute."""
@@ -61,4 +64,13 @@
         filenames.sort()
         for fn in filenames:
             fullpath = os.path.join(dirpath, fn)
-            yield (fullpath, file(fullpath, 'rb').read())
+            assert fullpath[-1] not in '@/'
+            info = os.lstat(fullpath)
+            if stat.S_ISLNK(info.st_mode):
+                yield (fullpath + '@', os.readlink(fullpath))
+            elif stat.S_ISREG(info.st_mode):
+                yield (fullpath, file(fullpath, 'rb').read())
+            else:
+                warning("can't capture file %s with mode %#o",
+                        fullpath, info.st_mode)
+                pass

=== added file 'tools/capture_tree.py'
--- tools/capture_tree.py	1970-01-01 00:00:00 +0000
+++ tools/capture_tree.py	2005-10-04 10:10:48 +0000
@@ -0,0 +1,30 @@
+#! /usr/bin/env python2.4
+
+# Copyright (C) 2005 Canonical Ltd
+
+"""Print to stdout a description of the current directory, 
+formatted as a Python data structure.
+
+This can be useful in tests that need to recreate directory
+contents."""
+
+# TODO: It'd be nice if this split long strings across 
+# multiple lines, relying on Python concatenation of consecutive
+# string constants.
+
+import sys
+import os
+import pprint
+
+from bzrlib.trace import enable_default_logging
+enable_default_logging()
+from bzrlib.selftest.treeshape import capture_tree_contents
+
+def main(argv):
+    print '['
+    for tt in capture_tree_contents('.'):
+        print `tt`, ','
+    print ']'
+
+if __name__ == '__main__':
+    sys.exit(main(sys.argv))

